==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Submit_News/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Printervenlig side");
define("_FRIEND","Send denne nyhed til en ven");
define("_YOURNAME","Dit navn");
define("_OK","Ok!");
define("_ALLOWEDHTML","Tilladte HTML-koder:");
define("_EXTRANS","Extrans (html-koder i teksten)");
define("_HTMLFORMATED","HTML-formateret");
define("_PLAINTEXT","Almindelig tekstformat");
define("_ARTICLES","Artikler");
define("_SUBMITNEWS","Indsend artikel");
define("_SUBMITADVICE","Skriv din artikel ved at udfylde nedenstende felter og kontroller dit indlg.<br>Det er ikke alle indlg der vil blive publiceret.<br>Dit indlg vil blive kontrolleret for stavning og tegnstning og bliver mske redigeret af vores team.");
define("_SUBTITLE","Overskrift");
define("_BEDESCRIPTIVE","Vr kort og prcis");
define("_BADTITLES","drlig overskrift='Tjek det her!' eller 'En artikel'");
define("_HTMLISFINE","Du m gerne bruge HTML-koder, men vr sikker p, at de er i orden og kontroller dem en ekstra gang!");
define("_AREYOUSURE","Har du angivet en internetadresse? Testede du for sl- og stavefejl?");
define("_SUBPREVIEW","Du skal gennemse artiklen mindst n gang fr du gemmer");
define("_SELECTTOPIC","Vlg emne");
define("_NEWSUBPREVIEW","Gennemse tekst");
define("_STORYLOOK","Din artikel vil se nogenlunde sdan ud:");
define("_CHECKSTORY","Vr venlig at kontrollere tekst, links osv. fr du sender dit indlg!");
define("_THANKSSUB","Tak for dit bidrag!");
define("_SUBSENT","Din artikel er modtaget...");
define("_SUBTEXT","Vi vil gennemse dit indlg snarest, hvis det er interessant og relevant, vil vi publicere det snarest.");
define("_WEHAVESUB","Lige nu er der");
define("_WAITING","indlg der venter p at blive publiceret.");
define("_PREVIEW","Gennemse");
define("_NEWUSER","Ny bruger");
define("_USCORE","Score");
define("_DATE","Dato");
define("_STORYTEXT","Manchet");
define("_EXTENDEDTEXT","Brdtekst");
define("_LANGUAGE","Language");
define("_JANUARY","January");
define("_FEBRUARY","February");
define("_MARCH","March");
define("_APRIL","April");
define("_MAY","May");
define("_JUNE","June");
define("_JULY","July");
define("_AUGUST","August");
define("_SEPTEMBER","September");
define("_OCTOBER","October");
define("_NOVEMBER","November");
define("_DECEMBER","December");
define("_SELECTMONTH2VIEW","Please select the month you want to view:");
define("_SHOWALLSTORIES","Show ALL Stories");
define("_STORIESARCHIVE","Stories Archive");
define("_ACTIONS","Actions");
define("_ARCHIVESINDEX","Stories Archive Index");
define("_ALLSTORIESARCH","All Stories");
define("_NEXTPAGE","Next Page");
define("_PREVIOUSPAGE","Previous Page");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Submit_News/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Printervenlig side");
define("_FRIEND","Send denne nyhed til en ven");
define("_YOURNAME","Dit navn");
define("_OK","Ok!");
define("_ALLOWEDHTML","Tilladte HTML-koder:");
define("_EXTRANS","Extrans (html-koder i teksten)");
define("_HTMLFORMATED","HTML-formateret");
define("_PLAINTEXT","Almindelig tekstformat");
define("_ARTICLES","Artikler");
define("_SUBMITNEWS","Indsend artikel");
define("_SUBMITADVICE","Skriv din artikel ved at udfylde nedenstende felter og kontroller dit indlg.<br>Det er ikke alle indlg der vil blive publiceret.<br>Dit indlg vil blive kontrolleret for stavning og tegnstning og bliver mske redigeret af vores team.");
define("_SUBTITLE","Overskrift");
define("_BEDESCRIPTIVE","Vr kort og prcis");
define("_BADTITLES","drlig overskrift='Tjek det her!' eller 'En artikel'");
define("_HTMLISFINE","Du m gerne bruge HTML-koder, men vr sikker p, at de er i orden og kontroller dem en ekstra gang!");
define("_AREYOUSURE","Har du angivet en internetadresse? Testede du for sl- og stavefejl?");
define("_SUBPREVIEW","Du skal gennemse artiklen mindst n gang fr du gemmer");
define("_SELECTTOPIC","Vlg emne");
define("_NEWSUBPREVIEW","Gennemse tekst");
define("_STORYLOOK","Din artikel vil se nogenlunde sdan ud:");
define("_CHECKSTORY","Vr venlig at kontrollere tekst, links osv. fr du sender dit indlg!");
define("_THANKSSUB","Tak for dit bidrag!");
define("_SUBSENT","Din artikel er modtaget...");
define("_SUBTEXT","Vi vil gennemse dit indlg snarest, hvis det er interessant og relevant, vil vi publicere det snarest.");
define("_WEHAVESUB","Lige nu er der");
define("_WAITING","indlg der venter p at blive publiceret.");
define("_PREVIEW","Gennemse");
define("_NEWUSER","Ny bruger");
define("_USCORE","Score");
define("_DATE","Dato");
define("_STORYTEXT","Manchet");
define("_EXTENDEDTEXT","Brdtekst");
define("_LANGUAGE","Language");

define("_SELECTMONTH2VIEW","Please select the month you want to view:");
define("_SHOWALLSTORIES","Show ALL Stories");
define("_STORIESARCHIVE","Stories Archive");
define("_ACTIONS","Actions");
define("_ARCHIVESINDEX","Stories Archive Index");
define("_ALLSTORIESARCH","All Stories");
define("_NEXTPAGE","Next Page");
define("_PREVIOUSPAGE","Previous Page");

?>
